# API Documentation

```{eval-rst}
.. currentmodule:: wikiglot
```

## Wiktionary Class

There is a single class in the `wikiglot` module, `Wiktionary`. It is the main entry point for parsing Wiktionary pages.

```{eval-rst}
.. currentmodule:: wikiglot

.. autosummary::
   :toctree: generated
   :template: class.rst

    Wiktionary
```
